@@ -8,7 +8,6 @@ from inflection import camelize, underscore
 from pymongo.collection import Collection
 from jsonclasses.fdef import FieldStorage, FieldType
 from jsonclasses.exceptions import UniqueConstraintException
-from jsonclasses.rtypes import rtypes
 from jsonclasses.exceptions import DeletionDeniedException
 from .pymongo_object import PymongoObject
 from .query import BaseQuery, ExistQuery, IterateQuery, ListQuery, SingleQuery, IDQuery
@@ -57,7 +56,7 @@ def _database_write(self: T) -> None:
         if self.__class__.dbconf.camelize_db_keys:
             pt_key = underscore(db_key)
             json_key = pt_key
-        if self.__class__.cdef.config.camelize_json_keys:
+        if self.__class__.cdef.jconf.camelize_json_keys:
             json_key = camelize(pt_key, False)
         raise UniqueConstraintException(
                 getattr(self, pt_key), json_key) from None
@@ -67,7 +66,7 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
     # deny test
     for field in self.__class__.cdef.deny_fields:
         if field.fdef.field_storage == FieldStorage.LOCAL_KEY:
-            key = self.__class__.cdef.config.key_transformer(field)
+            key = self.__class__.cdef.jconf.key_transformer(field)
             if hasattr(self, key) and getattr(self, key) is not None:
                 if no_raise:
                     return
@@ -75,11 +74,9 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                     raise DeletionDeniedException()
         elif field.fdef.field_storage == FieldStorage.FOREIGN_KEY:
             if field.fdef.field_type == FieldType.LIST:
-                t = rtypes(field.fdef.raw_item_types, self.__class__.cdef.config)
+                oc = field.fdef.item_types.fdef.inst_cls
             else:
-                t = rtypes(field.fdef.raw_inst_types, self.__class__.cdef.config)
-            types = t
-            oc = cast(type[PymongoObject], types.fdef.raw_inst_types)
+                oc = field.fdef.inst_cls
             f = cast(JField, field.foreign_field)
             if field.fdef.use_join_table:
                 jtname = Coder().join_table_name(
@@ -97,7 +94,7 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                     else:
                         raise DeletionDeniedException()
             else:
-                key = oc.cdef.config.key_transformer(f)
+                key = oc.cdef.jconf.key_transformer(f)
                 exist = oc.exist(**{key: ObjectId(self._id)}).exec()
                 if exist:
                     if no_raise:
@@ -112,11 +109,9 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
     for field in self.__class__.cdef.nullify_fields:
         if field.fdef.field_storage == FieldStorage.FOREIGN_KEY:
             if field.fdef.field_type == FieldType.LIST:
-                t = rtypes(field.fdef.raw_item_types, self.__class__.cdef.config)
+                oc = field.fdef.item_types.fdef.inst_cls
             else:
-                t = rtypes(field.fdef.raw_inst_types, self.__class__.cdef.config)
-            types = t
-            oc = cast(type[PymongoObject], types.fdef.raw_inst_types)
+                oc = field.fdef.inst_cls
             f = cast(JField, field.foreign_field)
             if field.fdef.use_join_table:
                 jtname = Coder().join_table_name(
@@ -128,7 +123,7 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                 key = ref_db_field_key(self.__class__.__name__, self.__class__)
                 coll.delete_many({key: ObjectId(self._id)})
             else:
-                key = oc.cdef.config.key_transformer(f)
+                key = oc.cdef.jconf.key_transformer(f)
                 for o in oc.iterate(**{key: ObjectId(self._id)}).exec():
                     setattr(o, f.name, None)
                     setattr(o, key, None)
@@ -137,14 +132,12 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
     # delete chain - cascade
     for field in self.__class__.cdef.cascade_fields:
         if field.fdef.field_type == FieldType.LIST:
-            t = rtypes(field.fdef.raw_item_types, self.__class__.cdef.config)
+            oc = field.fdef.item_types.fdef.inst_cls
         else:
-            t = rtypes(field.fdef.raw_inst_types, self.__class__.cdef.config)
-        types = t
-        oc = cast(type[PymongoObject], types.fdef.raw_inst_types)
+            oc = field.fdef.inst_cls
         f = cast(JField, field.foreign_field)
         if field.fdef.field_storage == FieldStorage.LOCAL_KEY:
-            key = self.__class__.cdef.config.key_transformer(field)
+            key = self.__class__.cdef.jconf.key_transformer(field)
             if getattr(self, key) is not None:
                 item = oc.id(getattr(self, key)).optional.exec()
                 if item is not None:
@@ -166,7 +159,7 @@ def _orm_delete(self: T, no_raise: bool = False) -> None:
                         item._orm_delete(no_raise=True)
                 coll.delete_many({key: ObjectId(self._id)})
             else:
-                key = oc.cdef.config.key_transformer(f)
+                key = oc.cdef.jconf.key_transformer(f)
                 for o in oc.iterate(**{key: ObjectId(self._id)}).exec():
                     o._orm_delete(no_raise=True)
 
@@ -195,7 +188,7 @@ def pymongofy(class_: type) -> PymongoObject:
     class_._orm_delete = _orm_delete
     class_._orm_restore = _orm_restore
     connection = Connection.from_class(class_)
-    if class_.cdef.config.abstract:
+    if class_.cdef.jconf.abstract:
         return class_
     def callback(coll: Collection):
         info = coll.index_information()
